"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@hibas123/utils");
const core_1 = require("@rtdb2/core");
class SettingComponent {
    constructor() {
        this.db = (0, core_1.getRawLevelDB)("databases/_server").data;
        this.databaseLock = new utils_1.Lock();
    }
    async setField(name, field, value) {
        return this.db.put("database:" + name + ":" + field, value);
    }
    async getField(name, field) {
        return this.db
            .get("database:" + name + ":" + field)
            .then((r) => r.toString())
            .catch(core_1.levelDBResNull);
    }
    getDatabaseList() {
        return this.db
            .get("databases")
            .then((res) => res.toString())
            .then((res) => res.split(":"))
            .catch((err) => err.notFound ? [] : Promise.reject(err));
    }
    async getDatabases() {
        const lock = await this.databaseLock.getLock();
        const databases = await this.getDatabaseList().then((res) => Promise.all(res.map(async (database) => {
            let res = {
                name: database,
            };
            await Promise.all([
                this.getField(database, "publickey").then((r) => (res.publickey = r)),
                this.getField(database, "rules").then((r) => (res.rules = r)),
                this.getField(database, "accesskey").then((r) => (res.accesskey = r)),
                this.getField(database, "rootkey").then((r) => (res.rootkey = r)),
            ]);
            return res;
        })));
        lock.release();
        return databases;
    }
    // hasDatabase(name: string): boolean {
    //    //TODO may require lock
    //    return this.databases.has(name);
    // }
    async addDatabase(name) {
        //TODO: Check for valid name
        if (name.indexOf(":") >= 0)
            throw new Error("Invalid Database name. Cannot contain ':'!");
        const lock = await this.databaseLock.getLock();
        let dbs = await this.getDatabaseList();
        dbs.push(name);
        await this.db.put("databases", dbs.join(":"));
        lock.release();
    }
    async setDatabasePublicKey(name, publickey) {
        const lock = await this.databaseLock.getLock();
        await this.setField(name, "publickey", publickey);
        lock.release();
    }
    async setDatabaseRules(name, rules) {
        const lock = await this.databaseLock.getLock();
        await this.setField(name, "rules", rules);
        lock.release();
    }
    async setDatabaseAccessKey(name, accesskey) {
        const lock = await this.databaseLock.getLock();
        await this.setField(name, "accesskey", accesskey);
        lock.release();
    }
    async setDatabaseRootKey(name, accesskey) {
        const lock = await this.databaseLock.getLock();
        await this.setField(name, "rootkey", accesskey);
        lock.release();
    }
    async deleteDatabase(name) {
        const lock = await this.databaseLock.getLock();
        let pref = "database:" + name;
        let dbs = await this.getDatabaseList().then((res) => res.filter((e) => e !== name));
        await this.db
            .batch()
            .put("databases", dbs.join(":"))
            .del(pref + ":publickey")
            .del(pref + ":rules")
            .del(pref + ":accesskey")
            .del(pref + ":rootkey")
            .write();
        lock.release();
    }
}
const Settings = new SettingComponent();
exports.default = Settings;
//# sourceMappingURL=settings.js.map