"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTemplate = exports.getView = void 0;
const Handlebars = require("handlebars");
const fs_1 = require("fs");
const config_1 = require("../../config");
const logging_1 = require("@hibas123/logging");
function checkCondition(v1, operator, v2) {
    switch (operator) {
        case "==":
            return v1 == v2;
        case "===":
            return v1 === v2;
        case "!==":
            return v1 !== v2;
        case "<":
            return v1 < v2;
        case "<=":
            return v1 <= v2;
        case ">":
            return v1 > v2;
        case ">=":
            return v1 >= v2;
        case "&&":
            return v1 && v2;
        case "||":
            return v1 || v2;
        default:
            return false;
    }
}
Handlebars.registerHelper("ifCond", function (v1, operator, v2, options) {
    return checkCondition(v1, operator, v2)
        ? options.fn(this)
        : options.inverse(this);
});
const cache = new Map();
const htmlCache = new Map();
function getView(name) {
    let tl;
    if (!config_1.default.dev)
        tl = htmlCache.get(name);
    if (!tl) {
        tl = (0, fs_1.readFileSync)(`./views/${name}.html`).toString();
        htmlCache.set(name, tl);
    }
    return tl;
}
exports.getView = getView;
function getTemplate(name) {
    let tl;
    if (!config_1.default.dev)
        tl = cache.get(name);
    if (!tl) {
        logging_1.default.debug("Recompiling template!");
        tl = Handlebars.compile((0, fs_1.readFileSync)(`./views/${name}.hbs`).toString());
        cache.set(name, tl);
    }
    return tl;
}
exports.getTemplate = getTemplate;
//# sourceMappingURL=hb.js.map