"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Router = require("koa-router");
const admin_1 = require("./admin");
const database_1 = require("../../database");
const errors_1 = require("../helper/errors");
const logging_1 = require("@hibas123/logging");
const core_1 = require("@rtdb2/core");
const nanoid_1 = require("nanoid");
const jwt_1 = require("../../helper/jwt");
const core_2 = require("@rtdb2/core");
const V1 = new Router({ prefix: "/v1" });
V1.use("/admin", admin_1.default.routes(), admin_1.default.allowedMethods());
V1.post("/db/:database/query", async (ctx) => {
    const { database } = ctx.params;
    const { accesskey, authkey, rootkey } = ctx.query;
    const query = ctx.request.body;
    if (!query) {
        throw new errors_1.BadRequestError("Query not defined!");
    }
    const session = new core_1.Session((0, nanoid_1.nanoid)());
    const db = database_1.DatabaseManager.getDatabase(database);
    if (!db) {
        throw new errors_1.NotFoundError("Database not found!");
    }
    if (db.accesskey) {
        if (!accesskey || accesskey !== db.accesskey) {
            throw new errors_1.NoPermissionError("Invalid Access Key");
        }
    }
    if (authkey && db.publickey) {
        let res = await (0, jwt_1.verifyJWT)(authkey, db.publickey);
        if (res && !res.uid && res.user)
            res.uid = res.user;
        if (!res || !res.uid) {
            throw new errors_1.BadRequestError("Invalid JWT");
        }
        else {
            session.uid = res.uid;
        }
    }
    if (rootkey && db.rootkey) {
        if (rootkey === db.rootkey) {
            session.root = true;
            logging_1.default.warning(`Somebody logged into ${database} via rootkey`);
        }
    }
    ctx.body = await db.database.run([query], session).catch((err) => {
        if (err instanceof core_2.QueryError) {
            throw new errors_1.BadRequestError(err.message);
        }
        throw err;
    });
});
exports.default = V1;
//# sourceMappingURL=index.js.map